@@ -37,7 +37,7 @@
 #define USAGE " [-Ehpv] [-u user] [-c n] [-C n:msg] [-b n] [-l name] [-i dir|-x cdb] [-t sec] host port prog"
 #endif
 
-#define VERSION "$Id: 89a81aa8a18cf69313cd62a5ce0aca2213db18e5 $"
+#define VERSION "$Id: 4f21b1c1026b4c301191b8ee0bc43f3f9090d52c $"
 
 #define FATAL "tcpsvd: fatal: "
 #define WARNING "tcpsvd: warning: "
@@ -321,7 +321,7 @@ int main(int argc, char **argv) {
   if (phccmax > cmax) phccmax =cmax;
 
   if (user)
-    if (! uidgid_get(&ugid, user, 1)) {
+    if (! uidgids_get(&ugid, user)) {
       if (errno)
         strerr_die4sys(111, FATAL, "unable to get user/group: ", user, ": ");
       strerr_die3x(100, FATAL, "unknown user/group: ", user);
@@ -332,7 +332,7 @@ int main(int argc, char **argv) {
   if ((getuid() == 0) && (! ssluser))
     strerr_die2x(100, FATAL, "-U ssluser must be set when running as root");
   if (ssluser)
-    if (! uidgid_get(&sslugid, ssluser, 1)) {
+    if (! uidgids_get(&sslugid, ssluser)) {
       if (errno)
         strerr_die4sys(111, FATAL, "unable to get user/group: ", ssluser, ": ");
       strerr_die3x(100, FATAL, "unknown user/group: ", ssluser);
@@ -387,7 +387,8 @@ int main(int argc, char **argv) {
 #else
   if (user) {
     /* drop permissions */
-    if (prot_gid(ugid.gid) == -1) fatal("unable to set gid");
+    if (setgroups(ugid.gids, ugid.gid) == -1) fatal("unable to set groups");
+    if (setgid(*ugid.gid) == -1) fatal("unable to set gid");
     if (prot_uid(ugid.uid) == -1) fatal("unable to set uid");
   }
 #endif
